@@ -27,7 +27,7 @@ while [[ "$#" -gt 0 ]]; do
 done
 
 # NOTE when adding/removing files, make sure to add use case to checkOutput function below
-UPSTREAM_JOB_NAME="crw-theia_${JOB_BRANCH}"
+UPSTREAM_JOB_NAME="crw-theia-sources_${JOB_BRANCH}"
 jenkinsURL="https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com/job/${UPSTREAM_JOB_NAME}"
 lastSuccessfulURL="${jenkinsURL}/lastSuccessfulBuild/api/xml?xpath=//" # id or description
 
@@ -158,6 +158,7 @@ function getFingerprints ()
 set +x
 # get list of the files we need from Jenkins, eg.,
 # https://codeready-workspaces-jenkins.rhev-ci-vms.eng.rdu2.redhat.com/view/CRW_CI/view/Pipelines/job/crw-theia_master/lastSuccessfulBuild/artifact/crw-theia/dockerfiles/theia/asset-list.txt
+theTarGzs=""
 assetList=asset-list.txt
 log "[INFO] Download asset list from ${jenkinsURL}/${assetPath}/${assetList}:"
 curl -sSLO ${jenkinsURL}/${assetPath}/${assetList}
@@ -166,6 +167,10 @@ for d in $(cat asset-list.txt | sort | uniq); do
 		theTarGzs="${theTarGzs} ${assetPath}/${d}"
 	fi
 done
+if [[ ! ${theTarGzs} ]]; then 
+	echo "[ERROR] No asset files found from ${jenkinsURL}/${assetPath}/${assetList} ! Check your ${UPSTREAM_JOB_NAME} is a valid job with valid artifacts!"
+	exit 1;
+fi
 rm -f ${assetList}
 set -x
 
